package jp.sourceforge.pdt_tools.adjustencoding.filters;

import java.util.Arrays;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IResource;

public class SampleFilter implements IFilter {

	private List<String> includeFolders = Arrays.asList();
	private List<String> includeFoldersRegEx = Arrays.asList();
	private List<String> includeFiles = Arrays.asList();
	private List<String> includeFilesRegEx = Arrays.asList(
			".*\\.[Hh][Tt][Mm]([Ll]|)", ".*\\.[Pp][Hh][Pp]");

	private List<String> excludeFolders = Arrays.asList("META-INF", "OSGI-INF",
			"WEB-INF", "bin");
	private List<String> excludeFoldersRegEx = Arrays.asList("\\..*");
	private List<String> excludeFiles = Arrays.asList();
	private List<String> excludeFilesRegEx = Arrays.asList("\\..*",
			".*\\.properties", ".*\\.x(ml|sd|sl)");

	public SampleFilter() {
	}

	@Override
	public boolean omit(IResource resource) {
		boolean result = false;
		if (resource instanceof IFolder) {
			result = filterFolder((IFolder) resource);
		}
		if (resource instanceof IFile) {
			result = filterFile((IFile) resource);
		}
		return result;
	}

	private boolean filterFolder(IFolder folder) {
		String name = folder.getName();
		if (includeFolders.contains(name)) {
			return false;
		}
		if (excludeFolders.contains(name)) {
			return true;
		}
		for (String regex : includeFoldersRegEx) {
			if (name.matches(regex)) {
				return false;
			}
		}
		for (String regex : excludeFoldersRegEx) {
			if (name.matches(regex)) {
				return true;
			}
		}
		return false;
	}

	private boolean filterFile(IFile file) {
		String name = file.getName();
		if (includeFiles.contains(name)) {
			return false;
		}
		if (excludeFiles.contains(name)) {
			return true;
		}
		for (String regex : includeFilesRegEx) {
			if (name.matches(regex)) {
				return false;
			}
		}
		for (String regex : excludeFilesRegEx) {
			if (name.matches(regex)) {
				return true;
			}
		}
		return false;
	}
}
